Previewer: Time ▲ Prism plugins

# How to use

You don't need to do anything. With this plugin loaded, a previewer will appear on hovering the time values in code blocks.

This plugin is compatible with CSS, Less, Sass, Scss and Stylus.

# Examples

## CSS

    div {
    	transition: all linear 3s;
    }

## Less

    @time: 1s;
    #header a {
    	transition: all linear 2s;
    }

## Sass

    $time: 3s
    @mixin foobar
    	transition: all linear 800ms
    .foo
    	transition: all linear 0.8s

## Scss

    $time: 1s;
    .foo {
    	transition: all linear 10s
    }

## Stylus

    time = 3s
    .foo
    	transition: all linear 0.5s